/* testing TestRGF.java, Rony G. Flatscher, 2001-04-21, 2003-05-10, 2005-05-05/06

   purpose: this Rexx program demonstrates the usage of the Java class "TestRGF" and
            demonstrates the usage of the BSF-interface, especially getting and setting
            values of fields

   invoke:  enter the following command to inoke the Rexx program "UseTestRGF.rex":

                  "java com.ibm.bsf.Main -lang rexx -in UseTestRGF.rex"
            or
                  "java com.ibm.bsf.Main -in UseTestRGF.rex"

            if extension "rex" is defined in the text file "\com\ibm\bsf\Languages.properties",
            which allows for determining the needed engine by looking at the file extension
*/

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

type = "TestRGF"                -- Java class name

say "Registering bean ..."

.bsf~import("testrgf", type)    -- import the Java class
tr1=.testrgf~new                -- create an instance

say "invoke toString() ..."
say left("", 79, "-")
say tr1~toString
say left("", 79, "-")

say "This came from Rexx."
say

say "invoke dump() ..."
say left("", 79, "-")
tr1~dump
say left("", 79, "-")
say "This came from Java."
say

if1 = tr1~getInstField1         -- invoking the Java defined field access method
say "if1="if1

sf1 = tr1~getStatField1         -- invoking the Java defined field access method
say "sf1="sf1

say
say "Now invoking the class' access methods, changing thereby the field values..."
tr1~setStatField1(sf1*1000)-- invoking the Java defined field set method
tr1~setInstField1(if1*1000)-- invoking the Java defined field set method

say
say "Now invoking the 'dump' method of the class:"
say left("", 79, "-")
tr1~dump
say left("", 79, "-")
say "This came from Java."

say
say "Now reading public fields *directly* with 'getFieldValue':"
say
say "statField1 [" || tr1~bsf.getFieldValue('statField1') || "] (a public static field)"
say "instField1 [" || tr1~bsf.getFieldValue('instField1') || "] (a public instance field)"
say left("", 40, "=")

say
say "instField2 [" || tr1~bsf.getFieldValue('instField2') || "] (a public instance field)"
say "instField3 [" || tr1~bsf.getFieldValue('instField3') || "] (a public instance field)"
say left("", 40, "=")
say

say left("", 40, "=")
say "Now setting public fields *directly* with 'setFieldValue' ..."
say
say "...new value for instField1: [" || tr1~bsf.setFieldValue('instField1', 1111) || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
say
say "...new value for instField2: [" || tr1~bsf.setFieldValue('instField2', 2222) || "] (a public instance field)"
say "   get value for instField2: [" || tr1~bsf.getFieldValue('instField2') || "]"
say
say "...new value for statField1: [" || tr1~bsf.setFieldValue('statField1', 9876) || "] (a public static field)"
say "   get value for statField1: [" || tr1~bsf.getFieldValue('statField1') || "]"
say

say "...new value for statField1: [" || tr1~bsf.setFieldValue('statField1', 6789) || "] (a public static field)"
say "   get value for statField1: [" || tr1~bsf.getFieldValue('statField1') || "]"
say


stmt="tr1~instField1=3333"
say "...new value for instField1: [" || stmt || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
stmt="tr1~instField1"
say "   get value for instField1: [" || stmt || "]=["tr1~instField1"]"
say

say "... setting field instField1: [" || 4444 || "]"
tr1~"instField1="(4444)
say "   get value for instField1: [" || stmt || "]=["tr1~instField1"]"
say

stmt="tr1~instField1=3333"
say "...new value for instField1: [" || stmt || "] (a public instance field)"
interpret stmt
tr1~instField1=3333
say "   get value for instField1: [" || stmt || "]=["tr1~instField1"]"
say

say "setting static field 'statField1' to 9009 ..."
tr1~statField1=9009
say "   get value for statField1: [" || tr1~statField1 || "]"
say


-- say "...new value for statField1: [" || (tr1~statField1=9009) || "] (a public static field)"
say "   get value for statField1: [" || tr1~statField1 || "]"
say "   getStaticValue for 'statField1': [" || .bsf~getStaticValue(tr1, "statField1") || "] bsf.gSF"
say "   getStaticValueStrict for 'statField1': [" || .bsf~getStaticValueStrict("TestRGF", "statField1") || "] bsf.gSFS"
-- say "   getStaticValueStrict for 'StatField1': [" || .bsf~getStaticValueStrict("TestRGF", "StatField1") || "] bsf.gSFS2"
say
say left("", 40, "=")
say
say "now using the newly developed function for public static fields: 'getStaticValue'"
say
say "the public static field named 'statField1' has the value:" "[" || .bsf~getStaticValue("TestRGF", "statField1") || "]"
say
say "getStatField99:" tr1~getStatField99
say "getInstField99:" tr1~getInstField99
say "setting a new STATIC value to 'statField99' (9999) via an instance..."
tr1~setStatField99(9999)
say "setting a new value to 'instField99' (-9999) via an instance..."
tr1~setInstField99(-9999)
say "getStatField99:" tr1~getStatField99
say "getInstField99:" tr1~getInstField99
say
say "getting class object for the instance referred to via 'tr1'..."
m=tr1~getClass
say "getting value getStatField99() via class object referred to via 'm':" m~getStatField99
say "setting a new value (1991) via the class object..."
m~setStatField99(1991)
say "getting value getStatField99() via class object referred to via 'm':" m~getStatField99
say

say "trying to get a field name via its implied getter method:"
say "tr1~instField99="tr1~instField99
say "tr1~statField99="tr1~statField99
say

say "--->" "(instField2, type: Object)"
say "...new value for instField2: [" || tr1~bsf.setFieldValueStrict('instField2', 2002) || "] (a public instance field)"
say "   get value for instField2: [" || tr1~bsf.getFieldValue('instField2') || "]"
say "...new value for instField2: [" || tr1~bsf.setFieldValueStrict('instField2', "i", 0220) || "] (a public instance field)"
say "   get value for instField2: [" || tr1~bsf.getFieldValue('instField2') || "]"
say "...new value for instField2: [" || tr1~bsf.setFieldValueStrict('instField2', "ST", 02020) || "] (a public instance field)"
say "   get value for instField2: [" || tr1~bsf.getFieldValue('instField2') || "]"
say "<---"
say

say "--->" "(instField1, type: int)"
say "...new value for instField1: [" || tr1~bsf.setFieldValueStrict('instField1', 2002) || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
say "...new value for instField1: [" || tr1~bsf.setFieldValueStrict('instField1', "i", 0220) || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
say "...new value for instField1: [" || tr1~bsf.setFieldValueStrict('instField1', "ST", 02020) || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
say "<---"
say


say "now setting the fields 'instField99' and 'statField99' to new values..."
tr1~instField99=12321      -- not availabe, try "setStatField99" afterwards
m  ~statField99=32123
say "tr1~instField99="tr1~instField99
say "tr1~statField99="tr1~statField99
say "tr1~statField9nixi9="tr1~statField9nixi9



::requires BSF.CLS            -- get the Object Rexx interface class


